/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.collection;

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertNull;
import static org.junit.jupiter.api.Assertions.assertSame;

/**
 * Validate {@link SoftCache}.
 *
 * @version $Id: 69f46d8020f50ffd9c86c99ae181cf7106bc8bb2 $
 */
class SoftCacheTest
{
    private SoftCache<String, String> cache = new SoftCache<>();

    @Test
    void testWithStrongReferences()
    {
        String value = "value";
        String defaultValue = "default";

        assertNull(this.cache.get(value));
        assertSame(defaultValue, this.cache.get(value, defaultValue));

        this.cache.put(value, value);

        assertSame(value, this.cache.get(value));
        assertSame(value, this.cache.get(value, defaultValue));
    }

    // TODO: find a way to force the JVM to clear all weak and soft references
}
