/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension.repository.xwiki.internal;

import java.net.URI;
import java.net.URISyntaxException;
import java.util.HashMap;
import java.util.Map;

import org.junit.jupiter.api.Test;
import org.xwiki.extension.repository.DefaultExtensionRepositoryDescriptor;
import org.xwiki.extension.repository.ExtensionRepository;
import org.xwiki.extension.repository.ExtensionRepositoryException;
import org.xwiki.test.junit5.mockito.ComponentTest;
import org.xwiki.test.junit5.mockito.InjectMockComponents;

import static org.junit.jupiter.api.Assertions.assertEquals;

/**
 * Validate {@link XWikiExtensionRepositoryFactory}.
 * 
 * @version $Id: 501d1b1d34e064a562034f424b4c0721363ae43f $
 */
@ComponentTest
class XWikiExtensionRepositoryFactoryTest
{
    @InjectMockComponents
    private XWikiExtensionRepositoryFactory factory;

    @Test
    void createRepository() throws ExtensionRepositoryException, URISyntaxException
    {
        Map<String, String> properties = new HashMap<>();
        properties.put("key", "value");

        ExtensionRepository repository = this.factory.createRepository(
            new DefaultExtensionRepositoryDescriptor("id", "xwiki", new URI("http://host"), properties));

        assertEquals("id", repository.getDescriptor().getId());
        assertEquals("xwiki", repository.getDescriptor().getType());
        assertEquals("http://host", repository.getDescriptor().getURI().toString());
        assertEquals(properties, repository.getDescriptor().getProperties());

        repository = this.factory.createRepository(
            new DefaultExtensionRepositoryDescriptor("id", "xwiki", new URI("http://host/"), properties));

        assertEquals("id", repository.getDescriptor().getId());
        assertEquals("xwiki", repository.getDescriptor().getType());
        assertEquals("http://host", repository.getDescriptor().getURI().toString());
        assertEquals(properties, repository.getDescriptor().getProperties());
    }
}
