/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.job.internal;

import java.io.File;

import org.junit.jupiter.api.Test;
import org.xwiki.configuration.ConfigurationSource;
import org.xwiki.environment.Environment;
import org.xwiki.test.annotation.AfterComponent;
import org.xwiki.test.junit5.mockito.ComponentTest;
import org.xwiki.test.junit5.mockito.InjectMockComponents;
import org.xwiki.test.junit5.mockito.MockComponent;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.mockito.Mockito.when;

/**
 * Validate {@link DefaultJobManagerConfiguration}.
 *
 * @version $Id: eba59dd69358d4596d8ff02837834f24cc37028f $
 */
@ComponentTest
public class DefaultJobManagerConfigurationTest
{
    @InjectMockComponents
    private DefaultJobManagerConfiguration configuration;

    @MockComponent
    private ConfigurationSource configurationSource;

    @MockComponent
    private Environment environment;

    private File permDir = new File("permDir");

    private File directory = new File("directory");

    @AfterComponent
    public void aftercomponents()
    {
        when(this.environment.getPermanentDirectory()).thenReturn(this.permDir);
    }

    @Test
    void getStorageWithProperty()
    {
        when(this.configurationSource.getProperty("job.statusFolder")).thenReturn(this.directory.toString());

        assertEquals(this.directory.getAbsoluteFile(), this.configuration.getStorage().getAbsoluteFile());
    }

    @Test
    void getStorageWithoutProperty()
    {
        assertEquals(new File(this.permDir, "jobs/status/").getAbsoluteFile(),
            this.configuration.getStorage().getAbsoluteFile());
    }
}
